@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.7.7.
+# This file is part of Merlin, Version: 1.8.0.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -35,11 +35,12 @@ import logging
 import os
 
 from celery import chain, chord, group, shared_task, signature
-from celery.exceptions import OperationalError, TimeoutError
+from celery.exceptions import MaxRetriesExceededError, OperationalError, TimeoutError
 
 from merlin.common.abstracts.enums import ReturnCode
 from merlin.common.sample_index import uniform_directories
 from merlin.common.sample_index_factory import create_hierarchy
+from merlin.config.utils import Priority, get_priority
 from merlin.exceptions import (
     HardFailException,
     InvalidChainException,
@@ -69,7 +70,12 @@ LOG = logging.getLogger(__name__)
 STOP_COUNTDOWN = 60
 
 
-@shared_task(bind=True, autoretry_for=retry_exceptions, retry_backoff=True)
+@shared_task(
+    bind=True,
+    autoretry_for=retry_exceptions,
+    retry_backoff=True,
+    priority=get_priority(Priority.high),
+)
 def merlin_step(self, *args, **kwargs):
     """
     Executes a Merlin Step
@@ -113,13 +119,29 @@ def merlin_step(self, *args, **kwargs):
         elif result == ReturnCode.DRY_OK:
             LOG.info(f"Dry-ran step '{step_name}' in '{step_dir}'.")
         elif result == ReturnCode.RESTART:
-            LOG.info(f"** Restarting step '{step_name}' in '{step_dir}'.")
             step.restart = True
-            raise RestartException
+            try:
+                LOG.info(
+                    f"Step '{step_name}' in '{step_dir}' is being restarted ({self.request.retries + 1}/{self.max_retries})..."
+                )
+                self.retry(countdown=step.retry_delay)
+            except MaxRetriesExceededError:
+                LOG.warning(
+                    f"*** Step '{step_name}' in '{step_dir}' exited with a MERLIN_RESTART command, but has already reached its retry limit ({self.max_retries}). Continuing with workflow."
+                )
+                result = ReturnCode.SOFT_FAIL
         elif result == ReturnCode.RETRY:
-            LOG.warning(f"** Retrying step '{step_name}' in '{step_dir}'.")
             step.restart = False
-            raise RetryException
+            try:
+                LOG.info(
+                    f"Step '{step_name}' in '{step_dir}' is being retried ({self.request.retries + 1}/{self.max_retries})..."
+                )
+                self.retry(countdown=step.retry_delay)
+            except MaxRetriesExceededError:
+                LOG.warning(
+                    f"*** Step '{step_name}' in '{step_dir}' exited with a MERLIN_RETRY command, but has already reached its retry limit ({self.max_retries}). Continuing with workflow."
+                )
+                result = ReturnCode.SOFT_FAIL
         elif result == ReturnCode.SOFT_FAIL:
             LOG.warning(
                 f"*** Step '{step_name}' in '{step_dir}' soft failed. Continuing with workflow."
@@ -213,7 +235,12 @@ def prepare_chain_workspace(sample_index, chain_):
         LOG.debug(f"...workspace {workspace} prepared.")
 
 
-@shared_task(bind=True, autoretry_for=retry_exceptions, retry_backoff=True)
+@shared_task(
+    bind=True,
+    autoretry_for=retry_exceptions,
+    retry_backoff=True,
+    priority=get_priority(Priority.low),
+)
 def add_merlin_expanded_chain_to_chord(
     self,
     task_type,
@@ -384,7 +411,12 @@ def add_chains_to_chord(self, all_chains):
     return ReturnCode.OK
 
 
-@shared_task(bind=True, autoretry_for=retry_exceptions, retry_backoff=True)
+@shared_task(
+    bind=True,
+    autoretry_for=retry_exceptions,
+    retry_backoff=True,
+    priority=get_priority(Priority.low),
+)
 def expand_tasks_with_samples(
     self,
     dag,
@@ -507,6 +539,7 @@ def expand_tasks_with_samples(
     acks_late=False,
     reject_on_worker_lost=False,
     name="merlin:shutdown_workers",
+    priority=get_priority(Priority.high),
 )
 def shutdown_workers(self, shutdown_queues):
     """
@@ -526,7 +559,10 @@ def shutdown_workers(self, shutdown_queues):
 
 
 @shared_task(
-    autoretry_for=retry_exceptions, retry_backoff=True, name="merlin:chordfinisher"
+    autoretry_for=retry_exceptions,
+    retry_backoff=True,
+    name="merlin:chordfinisher",
+    priority=get_priority(Priority.low),
 )
 def chordfinisher(*args, **kwargs):
     """.
@@ -540,7 +576,10 @@ def chordfinisher(*args, **kwargs):
 
 
 @shared_task(
-    autoretry_for=retry_exceptions, retry_backoff=True, name="merlin:queue_merlin_study"
+    autoretry_for=retry_exceptions,
+    retry_backoff=True,
+    name="merlin:queue_merlin_study",
+    priority=get_priority(Priority.low),
 )
 def queue_merlin_study(study, adapter):
     """
